pub enum HealthRequest {
GetReport {
responder: HealthGetReportResponder,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: HealthControlHandle,
method_type: MethodType,
},
}Expand description
Protocol for retrieving diagnostic and health information from the USB system.
Variants
GetReport
Returns a snapshot of the current USB health and device state.
Fields

responder: HealthGetReportResponder#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

control_handle: HealthControlHandle
method_type: MethodTypeImplementations
Sourceimpl HealthRequest
impl HealthRequest
pub fn into_get_report(self) -> Option<HealthGetReportResponder>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL