pub enum PolicyProviderRequest {
WatchDeviceState {
responder: PolicyProviderWatchDeviceStateResponder,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: PolicyProviderControlHandle,
method_type: MethodType,
},
}Expand description
An interface to monitor dynamic changes to the USB device state.
Variants
WatchDeviceState
Notify a client of an updated device state value via a hanging get. The first time this is called, it will return right away with the current state. Subsequent calls will hang until there is a change to report. Returns a table containing the updated device state.
Fields

responder: PolicyProviderWatchDeviceStateResponder#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

control_handle: PolicyProviderControlHandle
method_type: MethodTypeImplementations
Sourceimpl PolicyProviderRequest
impl PolicyProviderRequest
pub fn into_watch_device_state( self, ) -> Option<PolicyProviderWatchDeviceStateResponder>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL