pub struct AdbHealth {
pub status: Option<FunctionStatus>,
pub details: Option<String>,
pub online: Option<bool>,
pub driver_state: Option<String>,
/* private fields */
}Expand description
Health information for the USB ADB function subsystem.
Fields
status: Option<FunctionStatus>Describes the high-level policy and configuration state of the ADB function.
details: Option<String>Provides additional diagnostic details or state description.
online: Option<bool>Indicates whether the underlying ADB daemon connection and transport are actively online and
communicating with the host. In contrast to status == CONNECTED (which indicates the USB
peripheral function descriptor is configured and bound), online indicates that end-to-end
ADB transport is active.
driver_state: Option<String>Describes the runtime execution state reported by the ADB function driver (e.g. “kAwaitingUsbConnection”, “kOnline”, “kStoppingForReconnect”, “kStoppingForUnbind”).