pub struct ConfigurationProxy { /* private fields */ }Implementations
Sourceimpl ConfigurationProxy
impl ConfigurationProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.usb.policy/Configuration.
Sourcepub fn take_event_stream(&self) -> ConfigurationEventStream
pub fn take_event_stream(&self) -> ConfigurationEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn get_configuration(
&self,
) -> QueryResponseFut<ConfigurationGetConfigurationResult, DefaultFuchsiaResourceDialect> ⓘ
pub fn get_configuration( &self, ) -> QueryResponseFut<ConfigurationGetConfigurationResult, DefaultFuchsiaResourceDialect> ⓘ
Retrieves the current USB device descriptor and active configuration descriptors.
Errors
ZX_ERR_NOT_SUPPORTED: Peripheral function querying is not supported on the target hardware.
Sourcepub fn set_configuration(
&self,
device_desc: &DeviceDescriptor,
config_descriptors: &[Vec<FunctionDescriptor>],
) -> QueryResponseFut<ConfigurationSetConfigurationResult, DefaultFuchsiaResourceDialect> ⓘ
pub fn set_configuration( &self, device_desc: &DeviceDescriptor, config_descriptors: &[Vec<FunctionDescriptor>], ) -> QueryResponseFut<ConfigurationSetConfigurationResult, DefaultFuchsiaResourceDialect> ⓘ
Sets and activates a new USB peripheral function configuration.
Teardown of the previous peripheral function stack occurs before initializing and binding the newly specified functions. The call completes once the peripheral controller and underlying function drivers are registered and ready.
Errors
ZX_ERR_INVALID_ARGS: Configuration parameters are invalid.ZX_ERR_ALREADY_BOUND: An existing peripheral configuration is locked or undergoing transition.ZX_ERR_NOT_SUPPORTED: The requested combination of functions cannot be supported simultaneously.