pub struct PolicyProviderMarker;Trait Implementations
Sourceimpl Clone for PolicyProviderMarker
impl Clone for PolicyProviderMarker
Sourcefn clone(&self) -> PolicyProviderMarker
fn clone(&self) -> PolicyProviderMarker
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PolicyProviderMarker
impl Debug for PolicyProviderMarker
Sourceimpl Hash for PolicyProviderMarker
impl Hash for PolicyProviderMarker
Sourceimpl Ord for PolicyProviderMarker
impl Ord for PolicyProviderMarker
Sourcefn cmp(&self, other: &PolicyProviderMarker) -> Ordering
fn cmp(&self, other: &PolicyProviderMarker) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PolicyProviderMarker
impl PartialEq for PolicyProviderMarker
Sourceimpl PartialOrd for PolicyProviderMarker
impl PartialOrd for PolicyProviderMarker
Sourceimpl ProtocolMarker for PolicyProviderMarker
impl ProtocolMarker for PolicyProviderMarker
Sourceconst DEBUG_NAME: &'static str = "(anonymous) PolicyProvider"
const DEBUG_NAME: &'static str = "(anonymous) PolicyProvider"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = PolicyProviderProxy
type Proxy = PolicyProviderProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = PolicyProviderRequestStream
type RequestStream = PolicyProviderRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = PolicyProviderSynchronousProxy
type SynchronousProxy = PolicyProviderSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl Copy for PolicyProviderMarker
impl Eq for PolicyProviderMarker
impl StructuralPartialEq for PolicyProviderMarker