pub struct PolicyProviderProxy { /* private fields */ }Implementations
Sourceimpl PolicyProviderProxy
impl PolicyProviderProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.usb.policy/PolicyProvider.
Sourcepub fn take_event_stream(&self) -> PolicyProviderEventStream
pub fn take_event_stream(&self) -> PolicyProviderEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn watch_device_state(
&self,
) -> QueryResponseFut<DeviceStateWatcherWatchDeviceStateResult, DefaultFuchsiaResourceDialect>
pub fn watch_device_state( &self, ) -> QueryResponseFut<DeviceStateWatcherWatchDeviceStateResult, DefaultFuchsiaResourceDialect>
Notify a client of an updated device state value via a hanging get. The first time this is called, it will return right away with the current state. Subsequent calls will hang until there is a change to report. Returns a table containing the updated device state.