pub struct ConfigurationSynchronousProxy { /* private fields */ }Implementations
Sourceimpl ConfigurationSynchronousProxy
impl ConfigurationSynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<ConfigurationEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<ConfigurationEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn get_configuration(
&self,
___deadline: MonotonicInstant,
) -> Result<ConfigurationGetConfigurationResult, Error>
pub fn get_configuration( &self, ___deadline: MonotonicInstant, ) -> Result<ConfigurationGetConfigurationResult, Error>
Retrieves the current USB device descriptor and active configuration descriptors.
Errors
ZX_ERR_NOT_SUPPORTED: Peripheral function querying is not supported on the target hardware.
Sourcepub fn set_configuration(
&self,
device_desc: &DeviceDescriptor,
config_descriptors: &[Vec<FunctionDescriptor>],
___deadline: MonotonicInstant,
) -> Result<ConfigurationSetConfigurationResult, Error>
pub fn set_configuration( &self, device_desc: &DeviceDescriptor, config_descriptors: &[Vec<FunctionDescriptor>], ___deadline: MonotonicInstant, ) -> Result<ConfigurationSetConfigurationResult, Error>
Sets and activates a new USB peripheral function configuration.
Teardown of the previous peripheral function stack occurs before initializing and binding the newly specified functions. The call completes once the peripheral controller and underlying function drivers are registered and ready.
Errors
ZX_ERR_INVALID_ARGS: Configuration parameters are invalid.ZX_ERR_ALREADY_BOUND: An existing peripheral configuration is locked or undergoing transition.ZX_ERR_NOT_SUPPORTED: The requested combination of functions cannot be supported simultaneously.